Affiliations
------------

Scopus knows two types of affiliations: Org profiles and Non-Org profiles.

Org profiles are those entities that perform or sponsor research, such as a university, research institute, or government organization, which leads to the origination of documents by its members.  Affiliations that are org profiles (OrgID) according to Scopus start with a 6 (6XXXXXXX).  Scopus strives to have precise information about the institution, such as type and address.

Non-Org profiles correspond to automatically clustered profiles.  In theory, Non-Org profiles should correspond to research networks and virtual institutes, as they neither have a type nor an address.  Affiliations that are Non-Org profiles start with a 1 (1XXXXXXXX).  Often these are duplicates of Org profiles, which should be requested to be merged `here <https://service.elsevier.com/app/contact/supporthub/scopuscontent/>`_.
